import { motion } from "framer-motion";

export const LoginForm = ({ form, onSubmit, isLoading }) => {
    const { register, handleSubmit, formState: { errors } } = form;
    return (
        <motion.form
            initial={{ opacity: 0 }}
            animate={{ opacity: 1 }}
            exit={{ opacity: 0 }}
            className="space-y-6"
            onSubmit={handleSubmit(onSubmit)}
        >
            <h2 className="text-2xl font-bold text-white text-center mb-8">
                Sign In
            </h2>
            <div className="space-y-4">
                <div>
                    <input
                        {...register("username", {
                            required: "Username is required",
                            minLength: {
                                value: 2,
                                message: "Username must be at least 2 characters"
                            }
                        })}
                        className="w-full px-4 py-2 bg-white/10 border border-gray-600 
						   rounded-lg focus:ring-2 focus:ring-blue-500 
						   text-white placeholder-gray-400"
                        placeholder="Username"
                    />
                    {errors.username && (
                        <span className="text-red-400 text-sm mt-1">
                            {errors.username.message}
                        </span>
                    )}
                </div>

                <div>
                    <input
                        type="password"
                        {...register("password", {
                            required: "Password is required"
                        })}
                        className="w-full px-4 py-2 bg-white/10 border border-gray-600 
						   rounded-lg focus:ring-2 focus:ring-blue-500 
						   text-white placeholder-gray-400"
                        placeholder="Password"
                    />
                    {errors.password && (
                        <span className="text-red-400 text-sm mt-1">
                            {errors.password.message}
                        </span>
                    )}
                </div>
            </div>

            <button
                type="submit"
                disabled={isLoading}
                className="w-full py-2 px-4 bg-blue-600 text-white rounded-lg
					   hover:bg-blue-700 transition-colors duration-300
					   disabled:opacity-50 disabled:cursor-not-allowed"
            >
                {isLoading ? "Signing in..." : "Sign In"}
            </button>
        </motion.form>
    );
};