import { MagnifyingGlassIcon } from '@heroicons/react/24/outline';

interface SearchFiltersProps {
    searchTerm: string;
    onSearchChange: (value: string) => void;
    filterCategory: string;
    onCategoryChange: (value: string) => void;
    filterStatus: string;
    onStatusChange: (value: string) => void;
    className?: string
}
export function SearchFilters({
    searchTerm,
    onSearchChange,
    filterCategory,
    onCategoryChange,
    filterStatus,
    onStatusChange,
    className
}: SearchFiltersProps) {
    return (
        <div className={`flex flex-col sm:flex-row items-center gap-6 ${className}`}>
            <div className="flex-1 w-full">
                <div className="relative">
                    <MagnifyingGlassIcon className="h-5 w-5 text-[#041E42] absolute left-4 top-1/2 transform -translate-y-1/2" />
                    <input
                        type="text"
                        placeholder="Search by keyword, sender, or unit..."
                        className="w-full h-[46px] pl-12 pr-4  rounded-lg
                             bg-white shadow-sm transition-all duration-200
                             placeholder:text-gray-400
                             focus:outline-none focus:border-[#00308F] focus:ring-2 focus:ring-[#00308F]/20"
                        value={searchTerm}
                        onChange={(e) => onSearchChange(e.target.value)}
                    />
                </div>
            </div>
            <FilterDropdowns
                filterCategory={filterCategory}
                onCategoryChange={onCategoryChange}
                filterStatus={filterStatus}
                onStatusChange={onStatusChange}
            />
        </div>
    );
}

function FilterDropdowns({
    filterCategory,
    onCategoryChange,
    filterStatus,
    onStatusChange,
}: Pick<SearchFiltersProps, 'filterCategory' | 'onCategoryChange' | 'filterStatus' | 'onStatusChange'>) {
    const selectClassName = `min-w-[160px] h-[46px] px-4  rounded-lg
    bg-white shadow-sm transition-all duration-200
    text-[#041E42] font-medium
    focus:outline-none focus:border-[#00308F] focus:ring-2 focus:ring-[#00308F]/20
    hover:border-[#00308F]`;
    return (
        <div className="flex flex-col sm:flex-row gap-4">
            <select
                className={selectClassName}
                value={filterCategory}
                onChange={(e) => onCategoryChange(e.target.value)}
            >
                <option value="all">All Categories</option>
                <option value="complaint">Complaints</option>
                <option value="suggestion">Suggestions</option>
                <option value="request">Requests</option>
                <option value="feedback">Feedback</option>
            </select>
            <select
                className={selectClassName}
                value={filterStatus}
                onChange={(e) => onStatusChange(e.target.value)}
            >
                <option value="all">All Status</option>
                <option value="pending">Pending</option>
                <option value="in-progress">In Progress</option>
                <option value="resolved">Resolved</option>
            </select>
        </div>
    );
}