import { useState } from 'react'

interface FeedbackStatus {
    status: 'pending' | 'in-progress' | 'resolved'
    ticketId: string
    submittedDate: string
    lastUpdate: string
    title: string
}

export default function LetterProgressPage() {
    const [feedbackId, setFeedbackId] = useState('')
    const [status, setStatus] = useState<FeedbackStatus | null>(null)

    // Mock data - In production this would come from an API
    const mockLookup = () => {
        setStatus({
            status: 'in-progress',
            ticketId: 'USAF-2025-0123',
            submittedDate: '2025-01-15',
            lastUpdate: '2025-01-21',
            title: 'Aircraft Maintenance Schedule Inquiry'
        })
    }

    return (
        <div className="min-h-screen bg-gradient-to-b from-slate-100 to-slate-200">
            {/* Header */}
            <header className="bg-[#00308F] bg-gradient-to-r from-[#00308F] to-[#0353A4] p-6 text-white">
                <h1 className="text-2xl font-semibold mb-3">
                    USAF Feedback Progress Tracking
                </h1>
                <div className="text-lg opacity-90">
                    <p>请输入您的问题编号以查询处理进度</p>
                </div>
            </header>

            {/* Main Content */}
            <main className="container mx-auto px-4 py-8">
                {/* Search Section */}
                <div className="space-y-4 mb-8">
                    <label
                        htmlFor="feedbackId"
                        className="block text-lg font-medium text-[#1F4E79]"
                    >
                        Enter Feedback ID
                    </label>
                    <div className="flex gap-4">
                        <input
                            id="feedbackId"
                            type="text"
                            value={feedbackId}
                            onChange={(e) => setFeedbackId(e.target.value)}
                            placeholder="e.g. USAF-2025-0123"
                            className="flex-1 p-3 border border-gray-300 rounded-md focus:ring-2 focus:ring-[#00538B] focus:border-transparent"
                        />
                        <button
                            onClick={mockLookup}
                            className="px-6 py-3 bg-[#00538B] text-white rounded-md hover:bg-[#1F4E79] transition-colors duration-200"
                        >
                            Track
                        </button>
                    </div>
                </div>
                {/* Results Section */}
                {status && (
                    <div className="bg-white rounded-lg p-6">
                        <div className="space-y-6">
                            <div className="flex items-center justify-between border-b pb-4">
                                <h2 className="text-xl font-semibold text-[#1F4E79]">
                                    Feedback Details
                                </h2>
                                <span className="inline-flex items-center px-3 py-1 rounded-full text-sm font-medium bg-blue-100 text-[#00538B]">
                                    {status.status.toUpperCase()}
                                </span>
                            </div>

                            <div className="grid grid-cols-2 gap-4">
                                <div>
                                    <p className="text-sm text-gray-500">Ticket ID</p>
                                    <p className="font-medium">{status.ticketId}</p>
                                </div>
                                <div>
                                    <p className="text-sm text-gray-500">Submitted Date</p>
                                    <p className="font-medium">{status.submittedDate}</p>
                                </div>
                                <div>
                                    <p className="text-sm text-gray-500">Last Update</p>
                                    <p className="font-medium">{status.lastUpdate}</p>
                                </div>
                                <div>
                                    <p className="text-sm text-gray-500">Title</p>
                                    <p className="font-medium">{status.title}</p>
                                </div>
                            </div>

                            {/* Progress Timeline */}
                            <div className="mt-8">
                                <div className="relative">
                                    <div className="absolute w-full h-1 bg-gray-200 top-4"></div>
                                    <div className="relative flex justify-between">
                                        {['Submitted', 'In Review', 'Resolved'].map((step, index) => (
                                            <div key={step} className="text-center">
                                                <div className={`w-8 h-8 mx-auto rounded-full flex items-center justify-center ${index <= 1 ? 'bg-[#00538B] text-white' : 'bg-gray-200'
                                                    }`}>
                                                    {index + 1}
                                                </div>
                                                <div className="mt-2 text-sm font-medium">{step}</div>
                                            </div>
                                        ))}
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                )}
            </main>
        </div>
    )
}
